@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 2505 2007-07-06 17:34:19Z svn $
+ * $Id: mod_uploader.cpp 2538 2007-07-16 15:21:45Z svn $
  *****************************************************************************/
 
 /**
@@ -47,19 +47,17 @@
 #include "uploader_handler.h"
 
 #include "ApacheResponse.h"
-#include "ApacheLogger.h"
 #include "UploaderConfig.h"
 #include "Auxiliary.h"
 #include "Macro.h"
 #include "SourceInfo.h"
 
 #define TEMPLATE_INSTANTIATION
-#define RESPONSE_TYPE_APACHE
 #include "uploader_handler.cpp"
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2505 2007-07-06 17:34:19Z svn $");
+SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2538 2007-07-16 15:21:45Z svn $");
 
 static const char *HANDLER_NAME = "uploader";
 static apr_array_header_t *uploader_config_array = NULL;
